@@ -25,7 +25,6 @@ localconf=$BASE/new/devstack/local.conf
 echo "[[local|localrc]]" >> $localconf
 echo "DEVSTACK_GATE_TEMPEST_ALLOW_TENANT_ISOLATION=1" >> $localconf
 echo "API_RATE_LIMIT=False" >> $localconf
-echo "TEMPEST_SERVICES+=,manila" >> $localconf
 echo "VOLUME_BACKING_FILE_SIZE=22G" >> $localconf
 echo "CINDER_LVM_TYPE=thin" >> $localconf
 
@@ -125,7 +124,7 @@ elif [[ "$DRIVER" == "dummy" ]]; then
     echo "MANILA_OPTGROUP_membernet_standalone_network_plugin_network_type=vlan" >> $localconf
     echo "MANILA_OPTGROUP_membernet_standalone_network_plugin_segmentation_id=1010" >> $localconf
     echo "MANILA_OPTGROUP_membernet_standalone_network_plugin_allowed_ip_ranges=10.0.0.10-10.0.0.209" >> $localconf
-    echo "MANILA_OPTGROUP_membernet_standalone_network_plugin_ip_version=4" >> $localconf
+    echo "MANILA_OPTGROUP_membernet_network_plugin_ipv4_enabled=True" >> $localconf
 
     echo "MANILA_OPTGROUP_adminnet_network_api_class=manila.network.standalone_network_plugin.StandaloneNetworkPlugin" >> $localconf
     echo "MANILA_OPTGROUP_adminnet_standalone_network_plugin_gateway=11.0.0.1" >> $localconf
@@ -133,10 +132,9 @@ elif [[ "$DRIVER" == "dummy" ]]; then
     echo "MANILA_OPTGROUP_adminnet_standalone_network_plugin_network_type=vlan" >> $localconf
     echo "MANILA_OPTGROUP_adminnet_standalone_network_plugin_segmentation_id=1011" >> $localconf
     echo "MANILA_OPTGROUP_adminnet_standalone_network_plugin_allowed_ip_ranges=11.0.0.10-11.0.0.19,11.0.0.30-11.0.0.39,11.0.0.50-11.0.0.199" >> $localconf
-    echo "MANILA_OPTGROUP_adminnet_standalone_network_plugin_ip_version=4" >> $localconf
+    echo "MANILA_OPTGROUP_adminnet_network_plugin_ipv4_enabled=True" >> $localconf
 
     export MANILA_TEMPEST_CONCURRENCY=24
-    export MANILA_CONFIGURE_DEFAULT_TYPES=False
 
 elif [[ "$DRIVER" == "lvm" ]]; then
     MANILA_SERVICE_IMAGE_ENABLED=True
@@ -169,7 +167,6 @@ if [[ "$MANILA_SERVICE_IMAGE_ENABLED" == True ]]; then
     echo "MANILA_SERVICE_IMAGE_NAME=$MANILA_SERVICE_IMAGE_NAME" >> $localconf
 fi
 echo "MANILA_DEFAULT_SHARE_TYPE_EXTRA_SPECS=$DEFAULT_EXTRA_SPECS" >> $localconf
-echo "MANILA_CONFIGURE_DEFAULT_TYPES=${MANILA_CONFIGURE_DEFAULT_TYPES:-True}" >> $localconf
 
 # Enabling isolated metadata in Neutron is required because
 # Tempest creates isolated networks and created vm's in scenario tests don't
