@@ -568,6 +568,24 @@ class ShareAccessMapping(BASE, ManilaBase):
     )
 
 
+class ShareAccessRulesMetadata(BASE, ManilaBase):
+    """Represents a metadata key/value pair for a share access rule."""
+    __tablename__ = 'share_access_rules_metadata'
+    id = Column(Integer, primary_key=True)
+    deleted = Column(String(36), default='False')
+    key = Column(String(255), nullable=False)
+    value = Column(String(1023), nullable=False)
+    access_id = Column(String(36), ForeignKey('share_access_map.id'),
+                       nullable=False)
+    access = orm.relationship(
+        ShareAccessMapping, backref="share_access_rules_metadata",
+        foreign_keys=access_id,
+        lazy='immediate',
+        primaryjoin='and_('
+        'ShareAccessRulesMetadata.access_id == ShareAccessMapping.id,'
+        'ShareAccessRulesMetadata.deleted == "False")')
+
+
 class ShareInstanceAccessMapping(BASE, ManilaBase):
     """Represents access to individual share instances."""
 
@@ -875,6 +893,7 @@ class SecurityService(BASE, ManilaBase):
     password = Column(String(255), nullable=True)
     name = Column(String(255), nullable=True)
     description = Column(String(255), nullable=True)
+    ou = Column(String(255), nullable=True)
 
 
 class ShareNetwork(BASE, ManilaBase):
@@ -1066,10 +1085,10 @@ class ShareGroup(BASE, ManilaBase):
         ShareGroupTypes,
         backref="share_groups",
         foreign_keys=share_group_type_id,
-        primaryjoin='and_('
-                    'ShareGroup.share_group_type_id == '
-                    'ShareGroupTypes.id,'
-                    'ShareGroup.deleted == 0)')
+        primaryjoin="and_("
+                    "ShareGroup.share_group_type_id =="
+                    "ShareGroupTypes.id,"
+                    "ShareGroup.deleted == 'False')")
     _availability_zone = orm.relationship(
         "AvailabilityZone",
         lazy='immediate',
