@@ -42,7 +42,7 @@ CONF = cfg.CONF
 class ShareGroupSnapshotAPITest(test.TestCase):
 
     def setUp(self):
-        super(self.__class__, self).setUp()
+        super(ShareGroupSnapshotAPITest, self).setUp()
         self.controller = share_group_snapshots.ShareGroupSnapshotController()
         self.resource_name = self.controller.resource_name
         self.api_version = '2.31'
@@ -598,11 +598,5 @@ class ShareGroupSnapshotAPITest(test.TestCase):
         # Validate response code and model status
         self.assertEqual(valid_code, resp.status_int)
 
-        if valid_code == 404:
-            self.assertRaises(exception.NotFound,
-                              db.share_group_snapshot_get,
-                              ctxt,
-                              group_snap['id'])
-        else:
-            actual_model = db.share_group_snapshot_get(ctxt, group_snap['id'])
-            self.assertEqual(valid_status, actual_model['status'])
+        actual_model = db.share_group_snapshot_get(ctxt, group_snap['id'])
+        self.assertEqual(valid_status, actual_model['status'])
