@@ -47,7 +47,7 @@ class ShareGroupAPITest(test.TestCase):
     """Consistency Groups API Test suite."""
 
     def setUp(self):
-        super(self.__class__, self).setUp()
+        super(ShareGroupAPITest, self).setUp()
         self.controller = share_groups.ShareGroupController()
         self.resource_name = self.controller.resource_name
         self.fake_share_type = {'id': six.text_type(uuidutils.generate_uuid())}
@@ -936,13 +936,8 @@ class ShareGroupAPITest(test.TestCase):
         # validate response code and model status
         self.assertEqual(valid_code, resp.status_int)
 
-        if valid_code == 404:
-            self.assertRaises(
-                exception.NotFound,
-                db.share_group_get, ctxt, share_group['id'])
-        else:
-            actual_model = db.share_group_get(ctxt, share_group['id'])
-            self.assertEqual(valid_status, actual_model['status'])
+        actual_model = db.share_group_get(ctxt, share_group['id'])
+        self.assertEqual(valid_status, actual_model['status'])
 
     @ddt.data(*fakes.fixture_force_delete_with_different_roles)
     @ddt.unpack
