@@ -38,10 +38,9 @@ class ManilaCmdShareTestCase(test.TestCase):
         self.mock_object(self.launcher, 'launch_service')
         self.mock_object(self.launcher, 'wait')
         self.server = manila_share.service.Service.create.return_value
-        fake_host = 'fake_host'
-        CONF.set_override('enabled_share_backends', backends,
-                          enforce_type=True)
-        CONF.set_override('host', fake_host, enforce_type=True)
+        fake_host = 'fake.host'
+        CONF.set_override('enabled_share_backends', backends)
+        CONF.set_override('host', fake_host)
         sys.argv = ['manila-share']
 
         manila_share.main()
