@@ -61,6 +61,8 @@ class LintOutput(object):
     @classmethod
     def from_line(cls, line):
         m = re.search(r"(\S+):(\d+): \[(\S+)(, \S+)?] (.*)", line)
+        if m is None:
+            return None
         matched = m.groups()
         filename, lineno, code, message = (matched[0], int(matched[1]),
                                            matched[2], matched[-1])
@@ -82,7 +84,7 @@ class LintOutput(object):
         result = {}
         for line in msg.splitlines():
             obj = cls.from_line(line)
-            if obj.is_ignored():
+            if obj is None or obj.is_ignored():
                 continue
             key = obj.key()
             if key not in result:
@@ -138,8 +140,10 @@ class ErrorKeys(object):
 
 def run_pylint():
     buff = six.StringIO()
-    reporter = text.ParseableTextReporter(output=buff)
-    args = ["--include-ids=y", "-E", "manila"]
+    reporter = text.TextReporter(output=buff)
+    args = [
+        "--msg-template='{path}:{line}: [{msg_id}i({symbol}), {obj}] {msg}'",
+        "-E", "manila"]
     lint.Run(args, reporter=reporter, exit=False)
     val = buff.getvalue()
     buff.close()
